
#include "Camera.hpp"

Camera::Camera(Vector3f pos, float angle, Vector3f hpr,float near,float far,float gluangle)
{
	position = pos;
	axis = hpr;
	nearPlane = near;
	farPlane = far;
	gluAngle = gluangle;
	Angle = angle;
	eye.set(0,0,0);
	up.set(0,1,0);
	follow = false;
}

Camera::~Camera()
{

}

// call this before any other draw normally
void Camera::Draw()
{
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);	// Clear Screen And Depth Buffer
        glLoadIdentity();
	glViewport(0,0,(GLfloat)Graphics::screen.x,(GLfloat)Graphics::screen.y);
	glMatrixMode(GL_PROJECTION);						// Select The Projection Matrix
	glLoadIdentity();									// Reset The Projection Matrix

	// Calculate The Aspect Ratio Of The Window
//	gluPerspective(Angle,screenX/screenY,nearPlane,farPlane);
	gluPerspective(45.0f,(GLfloat)Graphics::screen.x/(GLfloat)Graphics::screen.y,nearPlane,farPlane);

	glMatrixMode(GL_MODELVIEW);							// Select The Modelview Matrix
	glLoadIdentity();
	glRotatef(Angle,axis.x,axis.y,axis.z);
	glRotatef(Angle,axis.y,axis.x,axis.z);

	if(!follow)
		gluLookAt(eye.x,eye.y,eye.z,targetPos.x,targetPos.y,targetPos.z,up.x,up.y,up.z);
	else
	{	
		gluLookAt(followPos.x + followOffset_b.x,followPos.y + followOffset_b.y,followPos.z + followOffset_b.z,
				followPos.x + followOffset_f.x,followPos.y + followOffset_f.y,followPos.z + followOffset_f.z,
					up.x,up.y,up.z);
	}
	//gluLookAt(0,5.0,-5.0,0,1.0,3.0,0,1,0);
}

Vector3f Camera::getPos()
{
	return position;
}

float Camera::getAngle()
{
	return Angle;
}

Vector3f Camera::getAxis()
{
	return axis;
}

float Camera::getNearPlane()
{
	return nearPlane;
}

float Camera::getFarPlane()
{
	return farPlane;
}

void Camera::setValues(Vector3f pos,float angle,Vector3f hpr,float npl,float fpl)
{
	position = pos;
	axis = hpr;
	nearPlane = npl;
	farPlane = fpl;
	Angle = angle;
}

void Camera::setTarget(Vector3f tPos)
{
	targetPos = tPos;
}

void Camera::setAngle(float angle)
{
	Angle = angle;
}

void Camera::setEye(Vector3f eyePos)
{
	eye = eyePos;
}

void Camera::Update(Character3D player)
{
	if(follow)
	{
		followPos = player.getPos();
	}
}

void Camera::Follow(Character3D player, Vector3f boffset,Vector3f foffset)
{
	follow = true;
	followPos = player.getPos();
	followOffset_b = boffset;
	followOffset_f = foffset;
}

void Camera::stopFollow()
{
	follow = false;
}


